import { ZodArray, ZodDiscriminatedUnion, ZodEffects, ZodLazy, ZodNullable, ZodObject, ZodTuple } from 'zod';
export function isStrictObjectSchema(schema) {
    return schema instanceof ZodObject;
}
function isWrappedFieldSchema(schema) {
    return schema instanceof ZodLazy || schema instanceof ZodEffects || schema instanceof ZodNullable;
}
export function unwrapFieldSchema(parent) {
    let unwrapped = parent;
    if (parent instanceof ZodLazy) {
        unwrapped = parent.schema;
    }
    else if (parent instanceof ZodEffects) {
        unwrapped = parent.innerType();
    }
    else if (parent instanceof ZodNullable) {
        unwrapped = parent.unwrap();
    }
    if (isWrappedFieldSchema(unwrapped)) {
        return unwrapFieldSchema(unwrapped);
    }
    return unwrapped;
}
export function isObjectOrListSchema(schema) {
    return isStrictObjectSchema(schema) || schema instanceof ZodArray || schema instanceof ZodTuple;
}
export function isFragmentsSchema(schema) {
    return schema instanceof ZodDiscriminatedUnion;
}
export function isUnionOrListSchema(schema) {
    return isFragmentsSchema(schema) || schema instanceof ZodArray || schema instanceof ZodTuple;
}
//# sourceMappingURL=query-schema.js.map